#include <sys/types.h>	/* notwendige ... */
#include <sys/stat.h>	/* ... Includes */
#include <stdio.h>

int main(int argc, char **argv) {
	struct stat statbuf;
	char *s;

	/* Usage-Meldung, falls nicht genau ein Argument */
	if (argc != 2) {
		fprintf(stderr, "Usage: %s <file>\n", argv[0]);
		exit(1);	/* Programm mit Exit-Status 1 terminieren */
	}

	/*
	 * Informationen ueber die Datei mit Name argv[1]
	 * beschaffen und in statbuf zurueckgeben;
	 * Rueckgabewert < 0 signalisiert Fehler
	 *
	 * Unterschied zw. stat() und lstat() (siehe auch man):
	 *
	 * Bei sog. symb. Links, das sind Alias-Namen, entdeckt
	 * lstat(), dass es sich um einen Alias handelt und stat()
	 * entdeckt das nicht. stat() kann fatal sein, wenn es
	 * Aliase auf Verz. gibt, so dass dann Zyklen entstehen.
	 *
	 * Bis auf diesen Unterschied verhalten sich beide stat-
	 * Varianten identisch.
	 */
	if (lstat(argv[1], &statbuf) < 0) {
		perror("stat()");
		exit(2);
	}

	/* Dateigroesse aus dem stat-Puffer lesen ... */
	printf("Dateigroesse: %d\n", statbuf.st_size);

	/* letzte Zugriffszeit aus dem stat-Puffer lesen ... */
	printf("Zeit: %d\n", statbuf.st_atime);

	/* Typ der Datei bestimmen ... */
	switch (statbuf.st_mode & S_IFMT) {
		case S_IFDIR : s = "Verzeichnis"; break;	/* es handelt sich um ein Verzeichnis */
		default: s = "etwas anderes"; break;	/* oder etwas anderes: gewoehnliche Datei, ... */
	}

	printf("Typ: %s\n", s);	/* Typ ausgeben */

	exit(0);
}
